==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/ProvisionedIdentity.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "id", 
    "displayName", 
    "identityType", 
    "details"})
@JsonInclude(Include.NON_NULL)
public class ProvisionedIdentity implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("id")
    protected String id;

    @JsonProperty("displayName")
    protected String displayName;

    @JsonProperty("identityType")
    protected String identityType;

    @JsonProperty("details")
    protected DetailsInfo details;

    protected ProvisionedIdentity() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.provisionedIdentity";
    }

    @Property(name="id")
    @JsonIgnore
    public Optional<String> getId() {
        return Optional.ofNullable(id);
    }

    public ProvisionedIdentity withId(String id) {
        ProvisionedIdentity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.provisionedIdentity");
        _x.id = id;
        return _x;
    }

    @Property(name="displayName")
    @JsonIgnore
    public Optional<String> getDisplayName() {
        return Optional.ofNullable(displayName);
    }

    public ProvisionedIdentity withDisplayName(String displayName) {
        ProvisionedIdentity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.provisionedIdentity");
        _x.displayName = displayName;
        return _x;
    }

    @Property(name="identityType")
    @JsonIgnore
    public Optional<String> getIdentityType() {
        return Optional.ofNullable(identityType);
    }

    public ProvisionedIdentity withIdentityType(String identityType) {
        ProvisionedIdentity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.provisionedIdentity");
        _x.identityType = identityType;
        return _x;
    }

    @Property(name="details")
    @JsonIgnore
    public Optional<DetailsInfo> getDetails() {
        return Optional.ofNullable(details);
    }

    public ProvisionedIdentity withDetails(DetailsInfo details) {
        ProvisionedIdentity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.provisionedIdentity");
        _x.details = details;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private String displayName;
        private String identityType;
        private DetailsInfo details;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder displayName(String displayName) {
            this.displayName = displayName;
            this.changedFields = changedFields.add("displayName");
            return this;
        }

        public Builder identityType(String identityType) {
            this.identityType = identityType;
            this.changedFields = changedFields.add("identityType");
            return this;
        }

        public Builder details(DetailsInfo details) {
            this.details = details;
            this.changedFields = changedFields.add("details");
            return this;
        }

        public ProvisionedIdentity build() {
            ProvisionedIdentity _x = new ProvisionedIdentity();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.provisionedIdentity";
            _x.id = id;
            _x.displayName = displayName;
            _x.identityType = identityType;
            _x.details = details;
            return _x;
        }
    }

    private ProvisionedIdentity _copy() {
        ProvisionedIdentity _x = new ProvisionedIdentity();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.displayName = displayName;
        _x.identityType = identityType;
        _x.details = details;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ProvisionedIdentity[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("displayName=");
        b.append(this.displayName);
        b.append(", ");
        b.append("identityType=");
        b.append(this.identityType);
        b.append(", ");
        b.append("details=");
        b.append(this.details);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/complex/ProvisionedIdentity.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "details", 
    "identityType"})
@JsonInclude(Include.NON_NULL)
public class ProvisionedIdentity extends Identity implements ODataType {

    @JsonProperty("details")
    protected DetailsInfo details;

    @JsonProperty("identityType")
    protected String identityType;

    protected ProvisionedIdentity() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.provisionedIdentity";
    }

    @Property(name="details")
    @JsonIgnore
    public Optional<DetailsInfo> getDetails() {
        return Optional.ofNullable(details);
    }

    public ProvisionedIdentity withDetails(DetailsInfo details) {
        ProvisionedIdentity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.provisionedIdentity");
        _x.details = details;
        return _x;
    }

    @Property(name="identityType")
    @JsonIgnore
    public Optional<String> getIdentityType() {
        return Optional.ofNullable(identityType);
    }

    public ProvisionedIdentity withIdentityType(String identityType) {
        ProvisionedIdentity _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.provisionedIdentity");
        _x.identityType = identityType;
        return _x;
    }

    public ProvisionedIdentity withUnmappedField(String name, Object value) {
        ProvisionedIdentity _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderProvisionedIdentity() {
        return new Builder();
    }

    public static final class Builder {
        private String displayName;
        private String id;
        private DetailsInfo details;
        private String identityType;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder displayName(String displayName) {
            this.displayName = displayName;
            this.changedFields = changedFields.add("displayName");
            return this;
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder details(DetailsInfo details) {
            this.details = details;
            this.changedFields = changedFields.add("details");
            return this;
        }

        public Builder identityType(String identityType) {
            this.identityType = identityType;
            this.changedFields = changedFields.add("identityType");
            return this;
        }

        public ProvisionedIdentity build() {
            ProvisionedIdentity _x = new ProvisionedIdentity();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.provisionedIdentity";
            _x.displayName = displayName;
            _x.id = id;
            _x.details = details;
            _x.identityType = identityType;
            return _x;
        }
    }

    private ProvisionedIdentity _copy() {
        ProvisionedIdentity _x = new ProvisionedIdentity();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.displayName = displayName;
        _x.id = id;
        _x.details = details;
        _x.identityType = identityType;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("ProvisionedIdentity[");
        b.append("displayName=");
        b.append(this.displayName);
        b.append(", ");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("details=");
        b.append(this.details);
        b.append(", ");
        b.append("identityType=");
        b.append(this.identityType);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
